@@ -19,14 +19,8 @@
 
 __docformat__ = "restructuredtext en"
 
-from datetime import datetime
 
-from twisted.web import http
-
-from cubicweb.web import DirectResponse
 from cubicweb.web.request import CubicWebRequestBase
-from cubicweb.web.httpcache import GMTOFFSET
-from cubicweb.web.http_headers import Headers
 
 
 class CubicWebTwistedRequestAdapter(CubicWebRequestBase):
@@ -39,6 +33,7 @@ class CubicWebTwistedRequestAdapter(CubicWebRequestBase):
                 self.form[key] = (name, stream)
             else:
                 self.form[key] = (unicode(name, self.encoding), stream)
+        self.content = self._twreq.content # stream
 
     def http_method(self):
         """returns 'POST', 'GET', 'HEAD', etc."""
