@@ -27,6 +27,7 @@ from ldap.filter import escape_filter_chars
 
 from rql.nodes import Relation, VariableRef, Constant, Function
 
+import warnings
 from cubicweb import UnknownEid, RepositoryError
 from cubicweb.server import ldaputils
 from cubicweb.server.utils import cartesian_product
@@ -45,6 +46,11 @@ PROTO_PORT = {'ldap': 389,
               }
 
 
+# module is lazily imported
+warnings.warn('Imminent drop of ldapuser. Switch to ldapfeed now!',
+              DeprecationWarning)
+
+
 class LDAPUserSource(ldaputils.LDAPSourceMixIn, AbstractSource):
     """LDAP read-only CWUser source"""
     support_entities = {'CWUser': False}
