@@ -17,8 +17,6 @@
 # with CubicWeb.  If not, see <http://www.gnu.org/licenses/>.
 """unit tests for cubicweb.web.application"""
 
-from __future__ import with_statement
-
 import base64, Cookie
 import sys
 from urllib import unquote
@@ -334,7 +332,7 @@ class ApplicationTC(CubicWebTC):
         self.assertAuthFailure(req)
         try:
             form = self.app_handle_request(req, 'login')
-        except Redirect, redir:
+        except Redirect as redir:
             self.fail('anonymous user should get login form')
         self.assertTrue('__login' in form)
         self.assertTrue('__password' in form)
